@@ -77,11 +77,16 @@ withr::with_options(list(pillar.bold = TRUE), {
     expect_pillar_output(paste(letters, collapse = ""), filename = "letters-long.txt")
     expect_pillar_output(paste(letters, collapse = ""), width = 10, filename = "letters-long-10.txt")
     expect_pillar_output(paste(letters, collapse = ""), width = 3, filename = "letters-long-03.txt")
+    expect_pillar_output(c("", " ", " a", "a ", "a b"), width = 5, filename = "spaces.txt")
+
+    skip_on_os("windows")
     expect_pillar_output("\u6210\u4ea4\u65e5", title = "\u6210\u4ea4", filename = "deal1.txt")
     expect_pillar_output("\u6210\u4ea4", title = "\u6210\u4ea4\u65e5", filename = "deal2.txt")
     expect_pillar_output(1L, title = "\u6210\u4ea4\u65e5", filename = "deal3.txt")
-    expect_pillar_output(c("", " ", " a", "a ", "a b"), width = 5, filename = "spaces.txt")
 
-    expect_pillar_output(xf = colonnade(chartype_frame()), width = 50, filename = "utf8.txt")
+    # Spurious warnings on Windows
+    suppressWarnings(
+      expect_pillar_output(xf = colonnade(chartype_frame()), width = 50, filename = "utf8.txt")
+    )
   })
 }) # withr::with_options(list(pillar.bold = TRUE), {
